@@ -3,17 +3,15 @@
 source $(dirname $0)/resolve.sh
 
 release=$1
-suffix=$2
 
-if [ $suffix = "ci" ]; then
-    output_file="openshift/release/knative-eventing-${suffix}.yaml"
-    image_prefix="registry.svc.ci.openshift.org/openshift/knative-${release}:knative-eventing-"
+output_file="openshift/release/knative-eventing-ci.yaml"
+
+if [ "$release" == "ci" ]; then
+    image_prefix="registry.svc.ci.openshift.org/openshift/knative-nightly:knative-eventing-"
     tag=""
 else
-    suffix=${release}
-    output_file="openshift/release/knative-eventing-${suffix}.yaml"
-    image_prefix="quay.io/openshift-knative/knative-eventing-"
-    tag=$release
+    image_prefix="registry.svc.ci.openshift.org/openshift/knative-${release}:knative-eventing-"
+    tag=""
 fi
 
 # the core parts
@@ -25,13 +23,13 @@ cat crd-channel-resolved.yaml >> $output_file
 rm crd-channel-resolved.yaml
 
 # the Channel Broker:
-output_file="openshift/release/knative-eventing-channelbroker-${suffix}.yaml"
+output_file="openshift/release/knative-eventing-channelbroker-ci.yaml"
 resolve_resources config/brokers/channel-broker/ channelbroker-resolved.yaml $image_prefix $tag
 cat channelbroker-resolved.yaml >> $output_file
 rm channelbroker-resolved.yaml
 
 # the MT Broker:
-output_file="openshift/release/knative-eventing-mtbroker-${suffix}.yaml"
+output_file="openshift/release/knative-eventing-mtbroker-ci.yaml"
 resolve_resources config/brokers/mt-channel-broker/ mtbroker-resolved.yaml $image_prefix $tag
 cat mtbroker-resolved.yaml >> $output_file
 rm mtbroker-resolved.yaml
